@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="de">
+<TS version="2.1" language="de_DE">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -120,6 +120,7 @@ Es wird mit einer einfachen Universalform gearbeitet.</translation>
     </message>
     <message>
         <source>%1 (%2)</source>
+        <extracomment>&lt;language&gt; (&lt;territory&gt;)</extracomment>
         <translation>%1 (%2)</translation>
     </message>
     <message>
@@ -162,33 +163,6 @@ Es wird mit einer einfachen Universalform gearbeitet.</translation>
         <translation>Unbekannter Fehler</translation>
     </message>
 </context>
-<context>
-    <name>FMT</name>
-    <message>
-        <source>GNU Gettext localization files</source>
-        <translation>GNU-Gettext-Übersetzungsdateien</translation>
-    </message>
-    <message>
-        <source>GNU Gettext localization template files</source>
-        <translation>Vorlagen für GNU-Gettext-Übersetzungsdateien</translation>
-    </message>
-    <message>
-        <source>Compiled Qt translations</source>
-        <translation>Kompilierte Qt-Übersetzungen</translation>
-    </message>
-    <message>
-        <source>Qt Linguist &apos;Phrase Book&apos;</source>
-        <translation>Qt-Linguist-Wörterbuch</translation>
-    </message>
-    <message>
-        <source>Qt translation sources</source>
-        <translation>Qt-Übersetzungsdateien</translation>
-    </message>
-    <message>
-        <source>XLIFF localization files</source>
-        <translation>XLIFF-Übersetzungsdateien</translation>
-    </message>
-</context>
 <context>
     <name>FindDialog</name>
     <message>
@@ -284,6 +258,26 @@ Es wird mit einer einfachen Universalform gearbeitet.</translation>
         <source>Regular &amp;expression</source>
         <translation>&amp;Regulärer Ausdruck</translation>
     </message>
+    <message>
+        <source>T&amp;ranslation status:</source>
+        <translation>Ü&amp;bersetzungsstatus:</translation>
+    </message>
+    <message>
+        <source>Lets you filter the search target by translation status</source>
+        <translation>Ermöglicht das Eingrenzen der Suche nach Übersetzungsstatus</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Alle</translation>
+    </message>
+    <message>
+        <source>Finished</source>
+        <translation>Erledigt</translation>
+    </message>
+    <message>
+        <source>Unfinished</source>
+        <translation>Unerledigt</translation>
+    </message>
 </context>
 <context>
     <name>FormMultiWidget</name>
@@ -311,37 +305,6 @@ Es wird mit einer einfachen Universalform gearbeitet.</translation>
         <translation>Soll die ausgefüllte Längenvariante gelöscht werden?</translation>
     </message>
 </context>
-<context>
-    <name>LRelease</name>
-    <message numerus="yes">
-        <source>Dropped %n message(s) which had no ID.</source>
-        <translation>
-            <numerusform>Es wurde ein Eintrag ohne Bezeichner gelöscht.</numerusform>
-            <numerusform>Es wurde %n Einträge ohne Bezeichner gelöscht.</numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>Excess context/disambiguation dropped from %n message(s).</source>
-        <translation>
-            <numerusform>Es wurde überflüssiger Kontext beziehungsweise überflüssige Infomation zur Unterscheidung bei einem Eintrag entfernt.</numerusform>
-            <numerusform>Es wurde überflüssiger Kontext beziehungsweise überflüssige Infomation zur Unterscheidung bei %n Einträgen entfernt.</numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>    Generated %n translation(s) (%1 finished and %2 unfinished)</source>
-        <translation>
-            <numerusform>    Eine Übersetzung wurde erzeugt (%1 abgeschlossen und %2 nicht abgeschlossen)</numerusform>
-            <numerusform>    %n Übersetzungen wurden erzeugt (%1 abgeschlossen und %2 nicht abgeschlossen)</numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>    Ignored %n untranslated source text(s)</source>
-        <translation>
-            <numerusform>    Ein nicht übersetzter Text wurde ignoriert</numerusform>
-            <numerusform>    %n nicht übersetzte Texte wurden ignoriert</numerusform>
-        </translation>
-    </message>
-</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -758,7 +721,7 @@ Es wird mit einer einfachen Universalform gearbeitet.</translation>
     </message>
     <message>
         <source>Batch translate all entries using the information in the phrase books.</source>
-        <translation>Alle Einträge automatisch mit Hilfe des Wörterbuchs übersetzen.</translation>
+        <translation>Alle Einträge automatisch mithilfe des Wörterbuchs übersetzen.</translation>
     </message>
     <message>
         <source>Release As...</source>
@@ -984,8 +947,8 @@ Alle Dateien (*)</translation>
         <translation>Version %1</translation>
     </message>
     <message>
-        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;Copyright (C) %2 The Qt Company Ltd.</source>
-        <translation>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;Copyright (C) %2 The Qt Company Ltd.</translation>
+        <source>Qt Linguist is a tool for adding translations to Qt applications.</source>
+        <translation>Qt Linguist ist ein Werkzeug zum Hinzufügen von Übersetzungen zu Qt-Anwendungen</translation>
     </message>
     <message>
         <source>Do you want to save the modified files?</source>
@@ -1020,12 +983,12 @@ Alle Dateien (*)</translation>
         <translation>Ctrl+M</translation>
     </message>
     <message>
-        <source>Display the manual for %1.</source>
-        <translation>Handbuch zu %1 anzeigen.</translation>
+        <source>Displays the manual for %1.</source>
+        <translation>Zeigt das Handbuch zu %1 an.</translation>
     </message>
     <message>
-        <source>Display information about %1.</source>
-        <translation>Informationen über %1 anzeigen.</translation>
+        <source>Displays information about %1.</source>
+        <translation>Zeigt Informationen über %1 an.</translation>
     </message>
     <message>
         <source>&amp;Save &apos;%1&apos;</source>
@@ -1318,6 +1281,22 @@ Alle Dateien (*)</translation>
         <source>Mark this item as done.</source>
         <translation>Diesen Eintrag als erledigt markieren.</translation>
     </message>
+    <message>
+        <source>Find P&amp;revious</source>
+        <translation>&amp;Rückwärts suchen</translation>
+    </message>
+    <message>
+        <source>Shift+F3</source>
+        <translation>Shift+F3</translation>
+    </message>
+    <message>
+        <source>&amp;QML preview</source>
+        <translation>&amp;QML-Vorschau</translation>
+    </message>
+    <message>
+        <source>Displays a preview of QML documents.</source>
+        <translation>Zeigt eine Vorschau von QML-Dokumenten.</translation>
+    </message>
 </context>
 <context>
     <name>MessageEditor</name>
@@ -1354,6 +1333,14 @@ Alle Dateien (*)</translation>
         <source>This area shows a comment that may guide you, and the context in which the text occurs.</source>
         <translation>Dieser Bereich zeigt eventuelle Kommentare und den Kontext, in dem der Text auftritt.</translation>
     </message>
+    <message>
+        <source>NCR mode</source>
+        <translation>NCR-Modus</translation>
+    </message>
+    <message>
+        <source>Toggles Numeric Character Reference Mode for displaying the source text and the translations.</source>
+        <translation>Schaltet den Modus für numerische Zeichen zur Anzeige von Quelltext und Übersetzung um.</translation>
+    </message>
     <message>
         <source>Here you can enter comments for your own use. They have no effect on the translated applications.</source>
         <translation>Hier können Sie Hinweise für den eigenen Gebrauch eintragen. Diese haben keinen Einflusse auf die Übersetzung.</translation>
@@ -1407,14 +1394,6 @@ Zeile: %2</translation>
         </translation>
     </message>
 </context>
-<context>
-    <name>MsgEdit</name>
-    <message>
-        <source></source>
-        <comment>This is the right panel of the main window.</comment>
-        <translation></translation>
-    </message>
-</context>
 <context>
     <name>PhraseBook</name>
     <message>
@@ -1616,6 +1595,34 @@ Zeile: %2</translation>
         <source>Close</source>
         <translation>Schließen</translation>
     </message>
+    <message>
+        <source>Unfinished</source>
+        <translation>Unerledigt</translation>
+    </message>
+    <message>
+        <source>Total translatable messages:</source>
+        <translation>Gesamtzahl übersetzbarer Einträge:</translation>
+    </message>
+    <message>
+        <source>Total finished:</source>
+        <translation>Gesamtzahl der erledigten Einträge:</translation>
+    </message>
+    <message>
+        <source>Without warnings:</source>
+        <translation>Ohne Warnungen:</translation>
+    </message>
+    <message>
+        <source>With warnings:</source>
+        <translation>Mit Warnungen:</translation>
+    </message>
+    <message>
+        <source>Unfinished:</source>
+        <translation>Unerledigt:</translation>
+    </message>
+    <message>
+        <source>Total messages including obsolete:</source>
+        <translation>Gesamtzahl einschließlich als &apos;obsolet&apos; gekennzeichneter Einträge:</translation>
+    </message>
 </context>
 <context>
     <name>TranslateDialog</name>
@@ -1680,12 +1687,12 @@ Zeile: %2</translation>
     <name>TranslationSettingsDialog</name>
     <message>
         <source>%1 (%2)</source>
-        <extracomment>&lt;english&gt; (&lt;endonym&gt;) (language and country names)</extracomment>
+        <extracomment>&lt;english&gt; (&lt;endonym&gt;) (language names)</extracomment>
         <translation>%1 (%2)</translation>
     </message>
     <message>
-        <source>Any Country</source>
-        <translation>Land</translation>
+        <source>Any Territory</source>
+        <translation>Beliebiges Territorium</translation>
     </message>
     <message>
         <source>Settings for &apos;%1&apos; - Qt Linguist</source>
@@ -1708,4 +1715,15 @@ Zeile: %2</translation>
         <translation>Zielsprache</translation>
     </message>
 </context>
+<context>
+    <name>QmlFormPreviewView</name>
+    <message>
+        <source>Qt Linguist</source>
+        <translation>Qt Linguist</translation>
+    </message>
+    <message>
+        <source>Error loading QML file: %1</source>
+        <translation>Fehler beim Laden der QML-Datei: %1</translation>
+    </message>
+</context>
 </TS>
