@@ -10,6 +10,13 @@ Please visit https://developers.arcgis.com/authentication/accessing-arcgis-onlin
 Bitte besuchen Sie https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</translation>
     </message>
 </context>
+<context>
+    <name>PlaceSearchReplyEsri</name>
+    <message>
+        <source>Response parse error</source>
+        <translation>Fehler beim Auswerten der Antwort</translation>
+    </message>
+</context>
 <context>
     <name>QDeclarativeGeoMap</name>
     <message>
@@ -63,6 +70,13 @@ Bitte besuchen Sie https://developers.arcgis.com/authentication/accessing-arcgis
         <translation>Das Plugin unterstützt keine (umgekehrte) Koordinatenbestimmung.</translation>
     </message>
 </context>
+<context>
+    <name>QGeoCodeReplyMapbox</name>
+    <message>
+        <source>Response parse error</source>
+        <translation>Fehler beim Auswerten der Antwort</translation>
+    </message>
+</context>
 <context>
     <name>QGeoMapMapboxGL</name>
     <message>
@@ -79,6 +93,18 @@ Bitte besuchen Sie https://developers.arcgis.com/authentication/accessing-arcgis
 </context>
 <context>
     <name>QGeoMappingManagerEngineMapboxGL</name>
+    <message>
+        <source>China Streets</source>
+        <translation>Straßen (chinesisch)</translation>
+    </message>
+    <message>
+        <source>China Light</source>
+        <translation>Hell (chinesisch)</translation>
+    </message>
+    <message>
+        <source>China Dark</source>
+        <translation>Dunkel (chinesisch)</translation>
+    </message>
     <message>
         <source>Streets</source>
         <translation>Straßen</translation>
@@ -514,6 +540,7 @@ Bitte besuchen Sie https://developers.arcgis.com/authentication/accessing-arcgis
     </message>
     <message>
         <source>Head %1</source>
+        <extracomment>%1 is &quot;North&quot;, &quot;South&quot;, &quot;East&quot; or &quot;West&quot;</extracomment>
         <translation>Fahren Sie %1</translation>
     </message>
     <message>
@@ -888,6 +915,7 @@ Bitte besuchen Sie https://developers.arcgis.com/authentication/accessing-arcgis
     </message>
     <message>
         <source> and continue straight</source>
+        <extracomment>This string will be prepended with lane instructions. E.g., &quot;Use the left or the right lane and continue straight&quot;</extracomment>
         <translation> und fahren Sie geradeaus weiter</translation>
     </message>
     <message>
@@ -1337,19 +1365,33 @@ Bitte besuchen Sie https://www.mapbox.com</translation>
         <translation>Netzwerkfehler</translation>
     </message>
 </context>
+<context>
+    <name>QPlaceSearchReplyMapbox</name>
+    <message>
+        <source>Response parse error</source>
+        <translation>Fehler beim Auswerten der Antwort</translation>
+    </message>
+</context>
 <context>
     <name>QPlaceSearchReplyOsm</name>
     <message>
         <source>Response parse error</source>
-        <translation>Fehler beim Parsen der Antwort</translation>
+        <translation>Fehler beim Auswerten der Antwort</translation>
+    </message>
+</context>
+<context>
+    <name>QPlaceSearchSuggestionReplyMapbox</name>
+    <message>
+        <source>Response parse error</source>
+        <translation>Fehler beim Auswerten der Antwort</translation>
     </message>
 </context>
 <context>
     <name>QtLocationQML</name>
     <message>
-        <source>Qt Location requires app_id and token parameters.
+        <source>Qt Location requires apiKey parameter.
 Please register at https://developer.here.com/ to get your personal application credentials.</source>
-        <translation>Qt Location benötigt die app_id und token Parameter.
+        <translation>Qt Location benötigt einen apiKey-Parameter.
 Bitte registrieren Sie sich unter https://developer.here.com/ um Ihre persönlichen Anmeldedaten zu erhalten.</translation>
     </message>
     <message>
